@@ -15,7 +15,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.22.0";
+our $VERSION = "v6.22.1";
 
 1;
 __END__
@@ -215,10 +215,10 @@ L<https://rxjs.dev/api/index/function/generate>
 
     # 2, 5, 10, 17, 26
     rx_generate(
-        1,
-        sub ($x) { $x <= 5 }, # could also use $_
-        sub ($x) { $x + 1 }, # could also use $_
-        sub ($x) { $x ** 2 + 1 }, # optional, and could also use $_ here
+        1, # initializer
+        sub ($x) { $x <= 5 }, # check, and can also use $_ here
+        sub ($x) { $x + 1 }, # iterate, and can also use $_ here
+        sub ($x) { $x ** 2 + 1 }, # result selector (optional), and can also use $_ here
     )->subscribe($observer);
 
 =item rx_iif
@@ -526,7 +526,7 @@ L<https://rxjs.dev/api/operators/count>
 
     # 3, complete
     rx_of(0, 1, 2, 3, 4, 5, 6)->pipe(
-        op_count(sub { $_[0] % 2 == 1 }), # could have also used $_ here instead of $_[0]
+        op_count(sub { $_[0] % 2 == 1 }), # can also use $_ here
     )->subscribe($observer);
 
     # 4, complete
@@ -708,7 +708,7 @@ L<https://rxjs.dev/api/operators/find>
 
     # 7, complete
     rx_interval(0.7)->pipe(
-        op_find(sub ($val, $idx) { $val == 7 }), # could use $_ here
+        op_find(sub ($val, $idx) { $val == 7 }), # can also use $_ here
     )->subscribe($observer);
 
     # undef, complete
@@ -724,7 +724,7 @@ L<https://rxjs.dev/api/operators/findIndex>
     # 7, complete
     rx_interval(0.7)->pipe(
         op_map(sub { $_ * 2 }),
-        op_find_index(sub ($val, $idx) { $val == 14 }), # could use $_ here
+        op_find_index(sub ($val, $idx) { $val == 14 }), # can also use $_ here
     )->subscribe($observer);
 
     # -1, complete
@@ -762,6 +762,18 @@ L<https://rxjs.dev/api/operators/groupBy>
         ),
     )->subscribe($observer);
 
+I<Note:> This implementation of this operator is a little bit buggy, and may result in
+resource leaks. For example, this will keep running forever:
+
+    my $subscription = rx_interval(0.7)->pipe(
+        op_group_by(sub { $_ % 2 }),
+    );
+
+    Mojo::IOLoop->timer(5, sub {
+        say "timer expired";
+        $subscription->unsubscribe;
+    });
+
 =item op_ignore_elements
 
 L<https://rxjs.dev/api/operators/ignoreElements>
@@ -803,7 +815,7 @@ L<https://rxjs.dev/api/operators/last>
 
     # 6, complete
     rx_of(5, 6, 7)->pipe(
-        op_last(sub ($val, $idx) { $val % 2 == 0 }), # could also use $_ here
+        op_last(sub ($val, $idx) { $val % 2 == 0 }), # can also use $_ here
     )->subscribe($observer);
 
     # 9, complete
@@ -1064,7 +1076,7 @@ L<https://rxjs.dev/api/operators/skipWhile>
 
     # 5, 3, 7, 1, complete
     rx_of(1, 3, 5, 3, 7, 1)->pipe(
-        op_skip_while(sub ($v, $idx) { $v < 4 }), # could use $_ here
+        op_skip_while(sub ($v, $idx) { $v < 4 }), # can also use $_ here
     )->subscribe($observer);
 
 =item op_start_with
